@@ -6,6 +6,7 @@ use std::{
     time::Duration,
 };
 
+use log::error;
 use rodio::{Decoder, OutputStream, Sink};
 
 use crate::home;
@@ -15,14 +16,32 @@ static CMD: AtomicU16 = AtomicU16::new(1);
 pub fn start_playback() {
     thread::spawn(move || {
         let filename = home::app_dir().join("eurostar-car.ogg");
-        let (_stream, stream_handle) = OutputStream::try_default().unwrap();
-        let sink = Sink::try_new(&stream_handle).unwrap();
+        let (_stream, stream_handle) = OutputStream::try_default().map_err(|err| {
+            error!("{}", err.to_string());
+            panic!("{}", err)
+        })
+        .unwrap();
+        let sink = Sink::try_new(&stream_handle).map_err(|err| {
+            error!("{}", err.to_string());
+            panic!("{}", err)
+        })
+        .unwrap();
 
         loop {
             if sink.empty() {
-                let file = BufReader::new(File::open(filename.clone()).unwrap());
-                let source = Decoder::new(file).unwrap();
-                sink.append(source);
+                let file = File::open(filename.clone()).map_err(|err| {
+                    error!("{}", err.to_string());
+                    panic!("{}", err)
+                })
+                .and_then(|file| Ok(BufReader::new(file)))
+                .unwrap();
+
+                let source = Decoder::new(file)
+                .and_then(|source| Ok(sink.append(source)));
+                if let Err(error) = source {
+                    error!("{}", error.to_string());
+                    panic!("{}", error)
+                }
             }
 
             match CMD.load(Ordering::Relaxed) {
